@@ -30,8 +30,8 @@
 extern "C" {
 #endif
 
-#define BLKID_VERSION   "2.32.0"
-#define BLKID_DATE      "21-Mar-2018"
+#define BLKID_VERSION   "2.33.1"
+#define BLKID_DATE      "09-Jan-2019"
 
 /**
  * blkid_dev:
